@@ -4,7 +4,7 @@
 
    Distributed under the GPL v2
    see the file COPYING for details
-   or visit http://www.gnu.org/copyleft/gpl.html
+   or visit https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 
    retrieves and displays information about a Matroska file
 
@@ -51,6 +51,8 @@ public:
   std::vector<std::string> m_frame_hexdumps;
   int64_t m_num_references{}, m_lf_timestamp{}, m_lf_tnum{};
   std::optional<int64_t> m_block_duration;
+  std::optional<uint64_t> m_block_add_id_type;
+  memory_cptr m_block_add_id_extra_data;
 
   bool m_use_gui{}, m_calc_checksums{}, m_show_summary{}, m_show_hexdump{}, m_show_size{}, m_show_positions{}, m_show_track_info{}, m_hex_positions{}, m_retain_elements{}, m_continue_at_cluster{}, m_show_all_elements{};
   int m_hexdump_max_size{};
