@@ -234,7 +234,7 @@ public:
   std::map<int64_t, display_properties_t> m_display_properties;
   double m_aspect_ratio;
   int m_display_width, m_display_height, m_display_unit;
-  bool m_aspect_ratio_given, m_aspect_ratio_is_factor, m_display_dimensions_given;
+  bool m_aspect_ratio_given, m_aspect_ratio_is_factor, m_aspect_ratio_factor_applied, m_display_dimensions_given;
   option_source_e m_display_dimensions_source;
 
   std::map<int64_t, timestamp_sync_t> m_timestamp_syncs; // As given on the command line
@@ -367,7 +367,6 @@ public:
   option_with_source_c<memory_cptr> m_color_space; // For this very track
 
   std::map<int64_t, std::pair<int64_t, bool>> m_default_durations; // As given on the command line
-  std::map<int64_t, int> m_max_blockadd_ids; // As given on the command line
 
   item_selector_c<attach_mode_e> m_attach_mode_list; // As given on the command line
 
