@@ -28,5 +28,15 @@ public:
     return YT("HEVC/H.265 (unframed)");
   };
 
+  virtual void handle_delayed_headers() override;
+
+  virtual void enable_dovi_layer_combiner();
+  virtual void process_enhancement_layer(packet_cptr const &packet);
+
   virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message) override;
+
+protected:
+  virtual void handle_dovi_block_addition_mappings();
+  virtual bool handle_dovi_configuration_record();
+  virtual void handle_dovi_enhancement_layer_configuration_record();
 };
